# cimcb_lite

### pip install: github
```console
pip install https://github.com/KevinMMendez/cimcb_lite/archive/master.zip
```

### pip install: github
```console
pip install cimcb_lite
```

### conda install: 
```console
conda install -c cimcb cimcb_lite
```
